@@ -1,11 +1,18 @@
+#' @title Phonetic Spelling Algorithms
+#' @docType package
+#' 
+#' @description
 #' Encode words with English-language Metaphone
 #'
+#' @details
 #' The phonics package provides an implementation of the Metaphone
 #' phonetic algorithm in R.  The algorithm reduces a string to a
 #' symbolic representation approximating the sound.  It can be used to
 #' match names, words, and as a proxy for assorted string distance
 #' algorithms.
 #'
-#' @family phonics
-#' @docType package
-#' @name phonics
+#' @author
+#' James P. Howard, II <jh@jameshoward.us>
+#'
+"_PACKAGE"
+#> [1] "_PACKAGE"
